## 4.2.0.20260402 (2026-04-02)

[ephem] Remove wrong protocol base classes ([#15587](https://github.com/python/typeshed/pull/15587))

## 4.2.0.20260116 (2026-01-16)

Add stubs for ephem ([#15191](https://github.com/python/typeshed/pull/15191))

